==> nextcloud-13.0.1.tgz: nextcloud/apps/survey_client/l10n/et_EE.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Kasutuse uuring",
    "Sent on: {on}" : "Saadetud: {on}",
    "An error occurred while sending your report." : "Raporti saatmisel tekkis viga.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Rakenduste nimekiri <em>(iga rakenduse kohta: nimi, versioon, olek)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Andmebaasikeskkond <em>(tüüp, versioon, suurus)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krüpteerimisteave <em>(kas on sisse lülitatud?, mis on vaikemoodul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Jagamiste hulk <em>(tüübi kohta ja õiguste seaded)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP keskkond <em>(versioon, mälupiirand, maksimaalne täitmisaeg, maksimaalne failisuurus)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Serveri instantsi üksikasjad <em>(versioon, memcache kasutamine, lukustamise/eelvaadete/avataride staatus)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistika <em>(failide, kasutajate, andmehoidla tüüpide, kommentaarite ja siltide arv)</em>",
    "Help improve Nextcloud" : "Aita Nextcloudi parendada",
    "Not now" : "Mitte praegu",
    "Send usage" : "Saada kasutusraport",
    "Never" : "Mitte kunagi",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Saad aidata kaasa Nextcloudi parendamisele, saates meile andmeid oma praeguse seadistuse ja kasutuse kohta.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Me võtame teie privaatsust tõsiselt. Andmete saatmine on vaikimisi välja lülitatud. Kui otsustate selle sisse lülitada, siis see tehakse kõigepealt anonüümseks ja antakse valida, mis andmeid jagada. Raporti kättesaamisel eelmine raport eemaldatakse. Lea üles puhas raport, et kustutada kõik andmed, mis praegu serveris salvestatud on.",
    "Send new report now" : "Saada kohe uus raport",
    "Send usage survey monthly" : "Saada kasutuse raport igakuiselt",
    "Data to send" : "Andmed, mida saata",
    "Last report" : "Viimane raport",
    "Sent on: %s" : "Saadetud: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Rakenduste nimekiri <em>(iga rakenduse kohta: nimi, versioon, kas on sisse lülitatud?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Serveri instantsi üksikasjad <em>(versioon, memcache kasutamine, lukustamine/eelvaated/avatarid sisse lülitatud?)</em>"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/survey_client/l10n/et_EE.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Kasutuse uuring",
    "An error occurred while sending your report." : "Raporti saatmisel tekkis viga.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Rakenduste nimekiri <em>(iga rakenduse kohta: nimi, versioon, olek)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Andmebaasikeskkond <em>(tüüp, versioon, suurus)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krüpteerimisteave <em>(kas on sisse lülitatud?, mis on vaikemoodul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Jagamiste hulk <em>(tüübi kohta ja õiguste seaded)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP keskkond <em>(versioon, mälupiirand, maksimaalne täitmisaeg, maksimaalne failisuurus)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Serveri instantsi üksikasjad <em>(versioon, memcache kasutamine, lukustamise/eelvaadete/avataride staatus)</em>",
    "Help improve Nextcloud" : "Aita Nextcloudi parendada",
    "Not now" : "Mitte praegu",
    "Send usage" : "Saada kasutusraport",
    "Never" : "Mitte kunagi",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Saad aidata kaasa Nextcloudi parendamisele, saates meile andmeid oma praeguse seadistuse ja kasutuse kohta.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Me võtame teie privaatsust tõsiselt. Andmete saatmine on vaikimisi välja lülitatud. Kui otsustate selle sisse lülitada, siis see tehakse kõigepealt anonüümseks ja antakse valida, mis andmeid jagada. Raporti kättesaamisel eelmine raport eemaldatakse. Lea üles puhas raport, et kustutada kõik andmed, mis praegu serveris salvestatud on.",
    "Send new report now" : "Saada kohe uus raport",
    "Send usage survey monthly" : "Saada kasutuse raport igakuiselt",
    "Data to send" : "Andmed, mida saata",
    "Last report" : "Viimane raport",
    "Sent on: {on}" : "Saadetud: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Rakenduste nimekiri <em>(iga rakenduse kohta: nimi, versioon, kas on sisse lülitatud?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Serveri instantsi üksikasjad <em>(versioon, memcache kasutamine, lukustamine/eelvaated/avatarid sisse lülitatud?)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistika <em>(failide, kasutajate, andmehoidla tüüpide, kommentaarite ja siltide arv)</em>",
    "Sent on: %s" : "Saadetud: %s"
},
"nplurals=2; plural=(n != 1);");
